## TODO List

- add attribute to SideEffect class to skip turns from certain players
- implement skills to find items on the map
- Add more skills for knight
- Add more custom skills
- Add more side-effects
- Add probability to side-effects
- Test Level up velocity
